@@ -12,23 +12,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 from pathlib import Path
-from typing import IO, TYPE_CHECKING, Any, Callable, Dict, Optional, Tuple, Type, Union
+from typing import IO, Any, Callable, Dict, Optional, Tuple, Type, Union
 
 import pytorch_lightning as pl
 import torch
 import transformers
 from pytorch_lightning.utilities import rank_zero_warn
-from transformers import AutoConfig, PreTrainedTokenizerBase
+from transformers import AutoConfig, Pipeline, PreTrainedTokenizerBase
 from transformers import pipeline as hf_transformers_pipeline
+from transformers.models.auto.auto_factory import _BaseAutoModelClass
 
+from lightning_transformers.utilities.deepspeed import enable_transformers_pretrained_deepspeed_sharding
 from lightning_transformers.utilities.imports import _ACCELERATE_AVAILABLE
 
 if _ACCELERATE_AVAILABLE:
     from accelerate import load_checkpoint_and_dispatch
 
-if TYPE_CHECKING:
-    from transformers import AutoModel, Pipeline
-
 
 class TaskTransformer(pl.LightningModule):
     """Base class for task specific transformers, wrapping pre-trained language models for downstream tasks. The
@@ -46,29 +45,45 @@ class TaskTransformer(pl.LightningModule):
 
     def __init__(
         self,
-        downstream_model_type: Type["AutoModel"],
+        downstream_model_type: Type[_BaseAutoModelClass],
         pretrained_model_name_or_path: Optional[str] = None,
         tokenizer: Optional[PreTrainedTokenizerBase] = None,
         pipeline_kwargs: Optional[dict] = None,
         load_weights: bool = True,
+        deepspeed_sharding: bool = False,
         **model_data_kwargs,
     ) -> None:
         super().__init__()
         self.save_hyperparameters()
-        if load_weights:
-            self.model = downstream_model_type.from_pretrained(pretrained_model_name_or_path, **model_data_kwargs)
-        else:
-            config = AutoConfig.from_pretrained(pretrained_model_name_or_path, **model_data_kwargs)
-            self.model = downstream_model_type.from_config(config)
+        self.load_weights = load_weights
+        self.model_data_kwargs = model_data_kwargs
+        self.downstream_model_type = downstream_model_type
+        self.deepspeed_sharding = deepspeed_sharding
+        self.pretrained_model_name_or_path = pretrained_model_name_or_path
+        if not self.deepspeed_sharding:
+            self.initialize_model(self.pretrained_model_name_or_path)
         self._tokenizer = tokenizer  # necessary for hf_pipeline
         self._hf_pipeline = None
         self._hf_pipeline_kwargs = pipeline_kwargs or {}
 
+    def initialize_model(self, pretrained_model_name_or_path: str):
+        """create and initialize the model to use with this task,
+
+        Feel free to overwrite this method if you are initializing the model in a different way
+        """
+        if self.load_weights:
+            self.model = self.downstream_model_type.from_pretrained(
+                pretrained_model_name_or_path, **self.model_data_kwargs
+            )
+        else:
+            config = AutoConfig.from_pretrained(pretrained_model_name_or_path, **self.model_data_kwargs)
+            self.model = self.downstream_model_type.from_config(config)
+
     def configure_optimizers(self) -> Dict:
         rank_zero_warn(
             "You haven't specified an optimizer or lr scheduler. "
             "Defaulting to AdamW with an lr of 1e-5 and linear warmup for 10% of steps. "
-            "To change this, override ``configure_optimizers`` in the TransformerModule."
+            "To change this, override ``configure_optimizers`` in  TransformerModule."
         )
         optimizer = torch.optim.AdamW(self.parameters(), lr=1e-5)
         num_training_steps, num_warmup_steps = self.compute_warmup(
@@ -98,6 +113,9 @@ class TaskTransformer(pl.LightningModule):
 
     def setup(self, stage: Optional[str] = None) -> None:
         self.configure_metrics(stage)
+        if self.deepspeed_sharding and not hasattr(self, "model"):
+            enable_transformers_pretrained_deepspeed_sharding(self)
+            self.initialize_model(self.pretrained_model_name_or_path)
 
     def configure_metrics(self, stage: str) -> Optional[Any]:
         """Override to configure metrics for train/validation/test.
@@ -107,7 +125,7 @@ class TaskTransformer(pl.LightningModule):
         pass
 
     @property
-    def tokenizer(self) -> Optional["PreTrainedTokenizerBase"]:
+    def tokenizer(self) -> Optional[PreTrainedTokenizerBase]:
         if (
             self._tokenizer is None
             and hasattr(self, "trainer")  # noqa: W503
@@ -118,7 +136,7 @@ class TaskTransformer(pl.LightningModule):
         return self._tokenizer
 
     @tokenizer.setter
-    def tokenizer(self, tokenizer: "PreTrainedTokenizerBase") -> None:
+    def tokenizer(self, tokenizer: PreTrainedTokenizerBase) -> None:
         self._tokenizer = tokenizer
 
     @property
@@ -130,7 +148,7 @@ class TaskTransformer(pl.LightningModule):
         return None
 
     @property
-    def hf_pipeline(self) -> "Pipeline":
+    def hf_pipeline(self) -> Pipeline:
         if self._hf_pipeline is None:
             if self.hf_pipeline_task is not None:
                 self._hf_pipeline = hf_transformers_pipeline(
@@ -141,7 +159,7 @@ class TaskTransformer(pl.LightningModule):
         return self._hf_pipeline
 
     @hf_pipeline.setter
-    def hf_pipeline(self, pipeline: "Pipeline") -> None:
+    def hf_pipeline(self, pipeline: Pipeline) -> None:
         self._hf_pipeline = pipeline
 
     def hf_predict(self, *args, **kwargs) -> Any:
