@@ -11,16 +11,14 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import TYPE_CHECKING, Type
+from typing import Type
 
 import transformers
 from torchmetrics.text.rouge import ROUGEScore
+from transformers.models.auto.auto_factory import _BaseAutoModelClass
 
 from lightning_transformers.core.seq2seq.model import Seq2SeqTransformer
 
-if TYPE_CHECKING:
-    from transformers import AutoModel
-
 
 class SummarizationTransformer(Seq2SeqTransformer):
     """Defines ``LightningModule`` for the Summarization Task.
@@ -36,7 +34,7 @@ class SummarizationTransformer(Seq2SeqTransformer):
     def __init__(
         self,
         *args,
-        downstream_model_type: Type["AutoModel"] = transformers.AutoModelForSeq2SeqLM,
+        downstream_model_type: Type[_BaseAutoModelClass] = transformers.AutoModelForSeq2SeqLM,
         use_stemmer: bool = True,
         **kwargs
     ) -> None:
